summaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
authorPascal Rigaux <pixel@mandriva.com>2000-09-26 16:15:03 +0000
committerPascal Rigaux <pixel@mandriva.com>2000-09-26 16:15:03 +0000
commitb3f38ef54228345b51813641a044a8bf615b3b95 (patch)
treeb29e83e84b22ffeba0b6512a416f18bab40e7a50
parent5088bd44d2469cbcd9e58ee8f6cae74bc9e43cfd (diff)
downloaddrakx-backup-do-not-use-b3f38ef54228345b51813641a044a8bf615b3b95.tar
drakx-backup-do-not-use-b3f38ef54228345b51813641a044a8bf615b3b95.tar.gz
drakx-backup-do-not-use-b3f38ef54228345b51813641a044a8bf615b3b95.tar.bz2
drakx-backup-do-not-use-b3f38ef54228345b51813641a044a8bf615b3b95.tar.xz
drakx-backup-do-not-use-b3f38ef54228345b51813641a044a8bf615b3b95.zip
no_comment
-rw-r--r--perl-install/ChangeLog9
-rw-r--r--perl-install/any.pm5
-rw-r--r--perl-install/help.pm67
-rw-r--r--perl-install/install_any.pm1
-rw-r--r--perl-install/install_gtk.pm2
-rw-r--r--perl-install/install_steps_interactive.pm64
-rw-r--r--perl-install/interactive_gtk.pm2
-rw-r--r--perl-install/modules.pm7
8 files changed, 124 insertions, 33 deletions
diff --git a/perl-install/ChangeLog b/perl-install/ChangeLog
index 2c3159b47..c5af9dce1 100644
--- a/perl-install/ChangeLog
+++ b/perl-install/ChangeLog
@@ -1,5 +1,14 @@
2000-09-26 Pixel <pixel@mandrakesoft.com>
+ * install_steps_interactive.pm (selectLanguage): integrate the
+ license (temporary one)
+
+ * modules.pm (write_conf): fix the /etc/modules generation
+
+ * interactive_gtk.pm (ask_many_from_listW): if more than 5 entries
+ in icon format, use scrollbar. In non-icon format, use scrollbar
+ for more than 11 entries.
+
* commands.pm (bug): add ddcxinfos
* pci_probing/pcitable: replace tulip by de4x5 for 2104x cards
diff --git a/perl-install/any.pm b/perl-install/any.pm
index c9cace407..f6220f4bb 100644
--- a/perl-install/any.pm
+++ b/perl-install/any.pm
@@ -502,10 +502,7 @@ sub setup_thiskind {
my $opt = [ __("Yes"), __("No") ];
push @$opt, __("See hardware info") if $::expert;
my $r = "Yes";
- unless ($at_least_one && @l == 0) {
- $::o->set_help('setupSCSIChoose') if $::isInstall;
- $r = $in->ask_from_list_('', $msg, $opt, "No");
- }
+ $r = $in->ask_from_list_('', $msg, $opt, "No") unless $at_least_one && @l == 0;
if ($r eq "No") { return @l }
if ($r eq "Yes") {
push @l, load_module($in, $type) || next;
diff --git a/perl-install/install_any.pm b/perl-install/install_any.pm
index 7ca6d11a6..fed856326 100644
--- a/perl-install/install_any.pm
+++ b/perl-install/install_any.pm
@@ -307,6 +307,7 @@ sub setPackages($) {
pkgs::readCompssUsers($o->{packages}, $o->{compss});
my @l = ();
+ push @l, 'xawtv', 'kwintv' if grep { $_->{driver} eq 'bttv' } detect_devices::probeall();
push @l, "kapm", "kcmlaptop", "DrakProfile", "DrakSync" if $o->{pcmcia};
push @l, "Glide_V5" if detect_devices::matching_desc('Voodoo 5');
push @l, "Glide_V3-DRI" if detect_devices::matching_desc('Voodoo (3|Banshee)');
diff --git a/perl-install/install_gtk.pm b/perl-install/install_gtk.pm
index ce7aeb537..019f5fa8a 100644
--- a/perl-install/install_gtk.pm
+++ b/perl-install/install_gtk.pm
@@ -427,7 +427,7 @@ sub test_mouse {
$draw_rect->(1, 0, [ 0, 0, $width, $height]);
$draw_text->(_("Please test the mouse"), 2 * $bh - 20);
$draw_text->(_("To activate the mouse,"), 2 * $bh + 10) if $mouse->{XMOUSETYPE} eq 'IMPS/2';
- $draw_text->(_("MOVE YOUR WHEEL!"), 2 * $bh + 20) if $mouse->{XMOUSETYPE} eq 'IMPS/2';
+ $draw_text->(_("MOVE YOUR WHEEL!"), 2 * $bh + 30) if $mouse->{XMOUSETYPE} eq 'IMPS/2';
$paintButton->($_, 0) foreach 0..2;
$w->{cancel}->grab_focus;
diff --git a/perl-install/install_steps_interactive.pm b/perl-install/install_steps_interactive.pm
index 66ef4faf1..a8adaa444 100644
--- a/perl-install/install_steps_interactive.pm
+++ b/perl-install/install_steps_interactive.pm
@@ -68,8 +68,68 @@ translated etc. that varies from language to language).") if $o->{lang} !~ /^en/
unless ($o->{useless_thing_accepted}) {
$o->set_help('license');
$o->{useless_thing_accepted} = $o->ask_from_list_('',
- "License - no warranty",
- [ __("Accept"), __("Refuse") ], "Accept") eq "Accept" or $o->exit;
+"Introduction
+
+\"Linux-Mandrake\" designates the operating system and the different
+components of the Linux-Mandrake distribution. The operating system and the
+different components available in the Linux-Mandrake distribution are
+called the \"Software Product\" hereafter. The Software Product includes, but
+is not restricted to, the set of programs, methods, rules, documentation,
+related to the operating system and the different components of the
+Linux-Mandrake distribution.
+
+1.License Agreement
+
+Please read carefully this document. This document is a license agreement
+between you and MandrakeSoft S.A., 42, rue d'Aboukir 75002 Paris - France,
+which applies to the Software Product.
+
+You must agree with the terms and conditions of the present License before
+you install, copy or use the Software Product. If you disagree with any
+portion of the License, you are not allowed to install, duplicate or use
+the Software. By installing, duplicating or using the Software Product in
+any manner, you explicitly accept and fully agree to conform to the terms
+and conditions of the present License. The License agreement is personal,
+non exclusive and non transferable.
+
+Any attempt to install, duplicate or use the Software Product in a manner
+which does not comply with the terms and conditions of the present License
+is void and will terminate your rights under the present License. Upon
+termination of the License, you must immediately destroy all copies of the
+Software Product.
+
+2. The GPL license and related licenses
+
+The Software product constists of components created by different persons
+or entities.
+
+Most of these components are governed under the terms and conditions of the
+GNU General Public License, hereafter called \"GPL\", or of similar
+licenses. Most of these licenses allow you to use, duplicate and adapt the
+components which they cover. Please read carefully the terms and conditions
+of the license agreement for each component before using the component. Any
+question on a component license should be addressed to the component author
+and not to MandrakeSoft.
+
+The programs and components developed by MandrakeSoft are usually governed
+by the GPL License. Please refer to the documentation of these components
+for further details.
+
+Some versions of the Software Product may contain components which are not
+governed by the GPL License or similar agreements. Each such component is
+then governed by the terms and conditions of its specific license. Please
+read carefully and comply with such specific licenses before you install,
+duplicate or use the said components. Such licenses will in general prevent
+the transfer, the duplication (except for backup purpose), the reverse
+engineering, de-assembly, de-compilation or modification of the
+component. Any breach of agreement will immediately terminate your rights
+under the specific license. Unless the specific license terms grant you
+such rights, you usually cannot install the programs on more than one
+system, or use it on a network. In doubt, please contact directly the
+distributor or editor of the component. Transfer to third parties or
+copying of such components including the documentation is strictly
+forbidden.
+", [ __("Accept"), __("Refuse") ], "Accept") eq "Accept" or $o->exit;
}
}
#------------------------------------------------------------------------------
diff --git a/perl-install/interactive_gtk.pm b/perl-install/interactive_gtk.pm
index ff1e48292..bd2063717 100644
--- a/perl-install/interactive_gtk.pm
+++ b/perl-install/interactive_gtk.pm
@@ -225,7 +225,7 @@ sub ask_many_from_listW {
my $f = $l->{icons}[$i];
-e $f ? gtkpack_(new Gtk::HBox(0,10), 0, new Gtk::Pixmap(gtkcreate_xpm($w->{window}, $f)), 1, $o) : $o;
} @{$l->{labels}});
- @{$l->{labels}} > 11 ? gtkset_usize(createScrolledWindow($box), @{$l->{icons}} ? 350 : 0, $::windowheight - 200) : $box;
+ @{$l->{labels}} > (@{$l->{icons}} ? 5 : 11) ? gtkset_usize(createScrolledWindow($box), @{$l->{icons}} ? 350 : 0, $::windowheight - 200) : $box;
} @l;
gtkadd($w->{window},
gtkpack_(create_box_with_title($w, @$messages),
diff --git a/perl-install/modules.pm b/perl-install/modules.pm
index a8b5c3939..f13c86ec2 100644
--- a/perl-install/modules.pm
+++ b/perl-install/modules.pm
@@ -558,14 +558,15 @@ sub write_conf {
print F "$type $mod $v2\n" if $v2 && $type ne "loaded" && !$written->{$mod}{$type};
}
}
- my @l = map { "scsi_hostadapter$_\n" } '', 1..$scsi-1 if $scsi;
+ my @l = map { "scsi_hostadapter$_" } '', 1..$scsi-1 if $scsi;
push @l, 'ide-floppy' if detect_devices::ide_zips();
push @l, 'bttv' if grep { $_->{driver} eq 'bttv' } detect_devices::probeall();
+ my $l = join '|', @l;
log::l("to put in modules @l");
substInFile {
- $_ = '' if /^scsi_hostadapter/;
- $_ = join '', @l if eof;
+ $_ = '' if /$l/;
+ $_ = join '', map { "$_\n" } @l if eof;
} "$prefix/etc/modules";
}
diff --git a/perl-install/help.pm b/perl-install/help.pm
index 294765557..4b006a8df 100644
--- a/perl-install/help.pm
+++ b/perl-install/help.pm
@@ -32,6 +32,7 @@ Please choose \"Rescue\" if you wish to rescue an already installed version of L
Depend of your knowledge in GNU/Linux, you can choose one of the following levels to install or rescue your
Linux-Mandrake operating system:
+
* Recommanded: if you have never installed a GNU/Linux operating system choose this. Installation will be
be very easy and you will be asked only on few questions.
@@ -58,6 +59,7 @@ selectInstallClassCorpo =>
selectInstallClass2 =>
__("You must now define your machine usage. Choices are:
+
* Workstation: this the ideal choice if you intend to use your machine primarily for everyday use, at office or
at home.
@@ -89,8 +91,6 @@ on retrieving this information from hardware documentation, from the
manufacturer's Web site (if you have Internet access) or from Microsoft Windows
(if you have it on your system)."),
-setupSCSIChoose => __("Please choose a driver for your SCSI adapter."),
-
doPartitionDisks => __("At this point, you need to choose where to install your
Linux-Mandrake operating system on your hard drive. If it is empty or if an
existing operating system uses all the space available on it, you need to
@@ -148,6 +148,7 @@ disk for partitioning by clicking on \"hda\" for the firs IDE drive, \"hdb\" for
the second or \"sda\" for the first SCSI drive and so on.
To partition the selected hard drive, you can use these options:
+
* Clear all: this option deletes all partitions available on the selected hard drive.
* Auto allocate:: this option allows you to automatically create Ext2 and swap partitions in free space of your
@@ -173,8 +174,11 @@ To partition the selected hard drive, you can use these options:
For information, you can reach any option using the keyboard: navigate trough the partitions using Tab and Up/Down
arrows. When a partition is selected, you can use:
+
* Ctrl-c to create a new partition (when a empty partition is selected)
+
* Ctrl-d to delete a partition
+
* Ctrl-m to set the mount point"),
ask_mntpoint_s => __("Above are listed the existing Linux partitions detected on
@@ -194,10 +198,15 @@ For information, each partition is listed as follows: \"Name\", \"Capacity\".
if it is an SCSI hard drive.
\"Hard drive number\" is always a letter after \"hd\" or \"sd\". With IDE hard drives:
+
* \"a\" means \"master hard drive on the primary IDE controller\",
- * \"b\" means \"slave hard drive on the primary IDE controller\",
+
+ * \"b\" means \"slave hard drive on the primary IDE controller\",
+
* \"c\" means \"master hard drive on the secondary IDE controller\",
+
* \"d\" means \"slave hard drive on the secondary IDE controller\".
+
With SCSI hard drives, a \"a\" means \"primary hard drive\", a \"b\" means \"secondary hard drive\", etc..."),
takeOverHdChoose => __("Choose the hard drive you want to erase to install your
@@ -226,10 +235,15 @@ name\" \"Capacity\".
if it is an SCSI hard drive.
\"Hard drive number\" is always a letter putted after \"hd\" or \"sd\". With IDE hard drives:
+
* \"a\" means \"master hard drive on the primary IDE controller\",
+
* \"b\" means \"slave hard drive on the primary IDE controller\",
+
* \"c\" means \"master hard drive on the secondary IDE controller\",
+
* \"d\" means \"slave hard drive on the secondary IDE controller\".
+
With SCSI hard drives, a \"a\" means \"primary hard drive\", a \"b\" means \"secondary hard drive\", etc.
\"Windows name\" is the letter of your hard drive under Windows (the first disk
@@ -388,9 +402,9 @@ will probably want not to start any services that you don't need. Please
remember that several services can be dangerous if they are enable on a server.
In general, select only the services that you really need."),
-configurePrinter => __("You can configure a local printer (connected to your
-computer) or remote printer (accessible via a Unix, Netware or Microsoft Windows
-network)."),
+configurePrinter =>
+__("You can configure a local printer (connected to your computer) or remote
+printer (accessible via a Unix, Netware or Microsoft Windows network)."),
configurePrinterSystem => __("
If you wish to be able to print, please choose one printing system between CUPS and LPR.
@@ -404,37 +418,44 @@ LPR is the old printing system used in previous Linux-Mandrake distributions.
If you don't have printer, click on \"None\"."),
configurePrinterConnected =>
-__("GNU/Linux can deal with many types of printer. Each of these types require a different setup.
+__("GNU/Linux can deal with many types of printer. Each of these types requires
+a different setup.
-If your printer is physically connected to your computer, select \"Local printer\".
+If your printer is physically connected to your computer, select \"Local
+printer\".
-If you want to access a printer located on a remote Unix machine, select \"Remote printer\".
+If you want to access a printer located on a remote Unix machine, select
+\"Remote printer\".
If you want to access a printer located on a remote Microsoft Windows machine
(or on Unix machine using SMB protocol), select \"SMB/Windows 95/98/NT\"."),
-configurePrinterLocal => __("Please turn on your printer before continue if you
-wish DrakX try to detect it.
+configurePrinterLocal =>
+__("Please turn on your printer before continuing to let DrakX detect it.
+
+You have to enter some informations here.
-You need to enter some informations here.
- * Name of printer: the print spooler uses \"lp\" as default printer name. So, you need have a printer named \"lp\".
+ * Name of printer: the print spooler uses \"lp\" as default printer name. So, you must have a printer named \"lp\".
If you have only one printer, you can use several names for it. You just need to separate them by a pipe
- character (a \"|\"). So, if you prefer to have a more meaningful name, you have to put it first, eg: \"My printer|lp\".
+ character (a \"|\"). So, if you prefer a more meaningful name, you have to put it first, eg: \"My printer|lp\".
The printer having \"lp\" in its name(s) will be the default printer.
- * Description: this optional but can be useful if several printers are connected on your computer or if you allow
+ * Description: this optional but can be useful if several printers are connected to your computer or if you allow
other computers to access to this printer.
- * Location: if you want to put some informations on where is your printer, put them here (you are free to write what
- you want)."),
+ * Location: if you want to put some information on your
+ printer location, put it here (you are free to write what
+ you want, for example \"2nd floor\").
+"),
-configurePrinterDev => __("Your printer have not been detected. Please enter
-name of device on which it is connected.
+configurePrinterDev =>
+__("Your printer has not been detected. Please enter the name of the device on
+which it is connected.
-For information, most of printers are connecter on first paralell port. This one
-is called \"/dev/lp0\" under GNU/Linux and \"LPT1\" under Microsoft Windows."),
+For information, most printers are connected on the first parallel port. This
+one is called \"/dev/lp0\" under GNU/Linux and \"LPT1\" under Microsoft Windows."),
-configurePrinterType => __("You now need to select your printer in list above."),
+configurePrinterType => __("You must now select your printer in the above list."),
setRootPassword => __("You can now enter the root password for your
Linux-Mandrake system. The password must be entered twice to verify that both
@@ -521,7 +542,9 @@ omitted or is set to zero.
- Video mode: This specifies the VGA text mode that should be selected
when booting. The following values are available:
+
* normal: select normal 80x25 text mode.
+
* <number>: use the corresponding text mode."),
setupSILOAddEntry =>